==> p5-Alien-wxWidgets-0.62.tgz: libdata/perl5/site_perl/i386-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'alien_base' => 'gtk2_gcc',
          'c_flags' => '-pthread ',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
          'prefix' => '/usr/local',
          '_libraries' => {
                            'richtext' => {
                                            'link' => '-lwx_gtk2_richtext',
                                            'dll' => 'libwx_gtk2_richtext.so.3.0'
                                          },
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     },
                            'base' => {
                                        'dll' => 'libwx_base.so.3.0',
                                        'link' => '-lwx_base'
                                      },
                            'qa' => {
                                      'link' => '-lwx_gtk2_qa',
                                      'dll' => 'libwx_gtk2_qa.so.3.0'
                                    },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'xrc' => {
                                       'dll' => 'libwx_gtk2_xrc.so.3.0',
                                       'link' => '-lwx_gtk2_xrc'
                                     },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                      },
                            'xml' => {
                                       'link' => '-lwx_base_xml',
                                       'dll' => 'libwx_base_xml.so.3.0'
                                     },
                            'gizmos' => {
                                          'link' => '-lwx_gtk2_gizmos',
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0'
                                        },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.3.0'
                                     },
                            'gl' => {
                                      'dll' => 'libwx_gtk2_gl.so.3.0',
                                      'link' => '-lwx_gtk2_gl'
                                    }
                          },
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'linker' => 'c++ -shared -fPIC  ',
          'compiler' => 'c++',
          'link_flags' => '',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
          'version' => '2.008012',
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'config' => {
                        'compiler_kind' => 'gcc',
                        'toolkit' => 'gtk2',
                        'compiler_version' => '3.4',
                        'unicode' => 0,
                        'mslu' => 0,
                        'debug' => 0,
                        'build' => 'multi'
                      }
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;

==> p5-Alien-wxWidgets-0.67p0.tgz: libdata/perl5/site_perl/i386-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          '_libraries' => {
                            'richtext' => {
                                            'link' => '-lwx_gtk2_richtext',
                                            'dll' => 'libwx_gtk2_richtext.so.3.0'
                                          },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.3.0'
                                     },
                            'core' => {
                                        'dll' => 'libwx_gtk2_core.so.3.0',
                                        'link' => '-lwx_gtk2_core'
                                      },
                            'xml' => {
                                       'dll' => 'libwx_base_xml.so.3.0',
                                       'link' => '-lwx_base_xml'
                                     },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    },
                            'xrc' => {
                                       'dll' => 'libwx_gtk2_xrc.so.3.0',
                                       'link' => '-lwx_gtk2_xrc'
                                     },
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.3.0'
                                    },
                            'adv' => {
                                       'link' => '-lwx_gtk2_adv',
                                       'dll' => 'libwx_gtk2_adv.so.3.0'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'media' => {
                                         'dll' => 'libwx_gtk2_media.so.3.0',
                                         'link' => '-lwx_gtk2_media'
                                       },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.3.0'
                                      }
                          },
          'config' => {
                        'mslu' => 0,
                        'toolkit' => 'gtk2',
                        'compiler_kind' => 'gcc',
                        'unicode' => 0,
                        'compiler_version' => '3.4',
                        'debug' => 0,
                        'build' => 'multi'
                      },
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'prefix' => '/usr/local',
          'link_flags' => '',
          'version' => '2.008012',
          'alien_base' => 'gtk2_gcc',
          'linker' => 'c++ -shared -fPIC  ',
          'compiler' => 'c++',
          'c_flags' => '-pthread ',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;
